/*
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *  Copyright (c) 2013 digitalSTROM.org, Zurich, Switzerland
 *  Author: Sibylle Kohler
 */

var progressBarWidth = 300;

/**
 * Extract parameter value from query string
 * @param name [in] name of the parameter
 * @returns the value of the parameter as string, empty string if parameter not found
 */
function getParameterByName(name)
{
  name = name.replace(/[\[]/, "\\[").replace(/[\]]/, "\\]");
  var regexS = "[\\?&]" + name + "=([^&#]*)";
  var regex = new RegExp(regexS);
  var results = regex.exec(window.location.search);
  if(results == null)
    return "";
  else
    return decodeURIComponent(results[1].replace(/\+/g, " "));
}

/**
 * Create a wait window with progress bar
 * 
 * @return {object} the created WaitDialog object
 */
function createWaitWindow() {
    var waitDialog;
    var progressBar = Ext.create('Ext.ProgressBar', {
        width: progressBarWidth,
        margin : '0 10 10 10' //top right bottom left
     });

    var ok = Ext.create('Ext.button.Button', {
        text : _("OK"),
        handler : function() {
            waitDialog.closeWindow();
        }
    });

    var buttonPanel = Ext.create('Ext.container.Container', {
       items : [ok],
       padding : '5 5 5 5',
       layout : {
           type : 'hbox',
           pack : 'center',
           align : 'middle'
       }
   });

   var dialogPanel = Ext.create('Ext.form.field.Display', {
       padding: '5 40 5 5', //top right bottom left
       border : 0,
       width : progressBarWidth,
       hideLabel : true,
       value : _("Please wait")     
   });

   waitDialog = Ext.create('Ext.window.Window',{
       modal : true, 
       layout : {
           type : 'vbox',
           align : 'center'
       },
       padding: '10 10 10 10', //top right bottom left
       header:true,
       title : _("Please wait"),
       closable:false,
       resizable: false,
       items: [dialogPanel, progressBar /*, buttonPanel*/],
       showWindow : function(sDialogText, bShowProgress) {
           if ((sDialogText !== undefined) && (sDialogText !== '')) {
               dialogPanel.setValue(sDialogText);
           }
           progressBar.setVisible(bShowProgress);
           progressBar.reset();
           progressBar.wait();
           this.show();
           this.center();
       },
       closeWindow : function() {
           progressBar.reset();
           this.hide();
       }
   });

    return waitDialog;
}
